==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1701.py <==
"""HeatTransferCoefficientForPlasticGearTooth"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_HEAT_TRANSFER_COEFFICIENT_FOR_PLASTIC_GEAR_TOOTH = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements",
    "HeatTransferCoefficientForPlasticGearTooth",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="HeatTransferCoefficientForPlasticGearTooth")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HeatTransferCoefficientForPlasticGearTooth._Cast_HeatTransferCoefficientForPlasticGearTooth",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HeatTransferCoefficientForPlasticGearTooth",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HeatTransferCoefficientForPlasticGearTooth:
    """Special nested class for casting HeatTransferCoefficientForPlasticGearTooth to subclasses."""

    __parent__: "HeatTransferCoefficientForPlasticGearTooth"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def heat_transfer_coefficient_for_plastic_gear_tooth(
        self: "CastSelf",
    ) -> "HeatTransferCoefficientForPlasticGearTooth":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class HeatTransferCoefficientForPlasticGearTooth(_1652.MeasurementBase):
    """HeatTransferCoefficientForPlasticGearTooth

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HEAT_TRANSFER_COEFFICIENT_FOR_PLASTIC_GEAR_TOOTH

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_HeatTransferCoefficientForPlasticGearTooth":
        """Cast to another type.

        Returns:
            _Cast_HeatTransferCoefficientForPlasticGearTooth
        """
        return _Cast_HeatTransferCoefficientForPlasticGearTooth(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1701.py <==
"""Enum"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_ENUM = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Enum"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Enum")
    CastSelf = TypeVar("CastSelf", bound="Enum._Cast_Enum")


__docformat__ = "restructuredtext en"
__all__ = ("Enum",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Enum:
    """Special nested class for casting Enum to subclasses."""

    __parent__: "Enum"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def enum(self: "CastSelf") -> "Enum":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Enum(_1666.MeasurementBase):
    """Enum

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ENUM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Enum":
        """Cast to another type.

        Returns:
            _Cast_Enum
        """
        return _Cast_Enum(self)
